summaryrefslogtreecommitdiff
path: root/src/display.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/display.rs')
-rw-r--r--src/display.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/display.rs b/src/display.rs
index a237a10f..733c66e8 100644
--- a/src/display.rs
+++ b/src/display.rs
@@ -411,7 +411,7 @@ impl Display {
self.window.get_window_id()
}
/// Adjust the XIM editor position according to the new location of the cursor
pub fn update_ime_position(&mut self, terminal: &Term) {
use index::{Point, Line, Column};
use term::SizeInfo;
@@ -420,8 +420,8 @@ impl Display {
cell_height: ch,
padding_x: px,
padding_y: py, ..} = *terminal.size_info();
- let nspot_y = (py + (row + 1) as f32 * ch) as i16;
- let nspot_x = (px + col as f32 * cw) as i16;
- self.window().send_xim_spot(nspot_x, nspot_y);
+ let nspot_y = (py + (row + 1) as f32 * ch) as i32;
+ let nspot_x = (px + col as f32 * cw) as i32;
+ self.window().set_ime_spot(nspot_x, nspot_y);
}
}
@@ -411,7 +411,7 @@ impl Display {
self.window.get_window_id()
}
- /// Adjust the XIM editor position according to the new location of the cursor
+ /// Adjust the IME editor position according to the new location of the cursor
pub fn update_ime_position(&mut self, terminal: &Term) {
use index::{Point, Line, Column};